#!/usr/bin/perl 
# asmlib
#
# assembles the library defined in <libname>.lib.def
#
# usage: asmlib.pl [-sd=<sourcedir>] [-td=<targetdir>] <libname>
#
# The <libname>.lib.def is assumed to be in <sourcedir>.
# In case <sourcedir> or <targetdir> are not specified, the current directory
# is assumed.

use strict;
use bytes;
my $DEBUG = 1;

my @t;
my $sd=""; # source directory
my $td=""; # target directory
my $sdir="current";
my $tdir="current";
my $fi="";

my $arg;                            # current argument
my $narg=0;                         # argument number

while( ($arg = shift (@ARGV)) ne "" && $narg < 3)
{
	$narg=$narg+1;
	if($DEBUG) {print "ARG$narg:$arg\n";}
	if ($arg !~ /\-/ && $arg ne "")
	{
		$fi=$arg;
	}
	elsif ($arg =~ /\-/)
	{
		@t=split(/\=/,$arg);
		if($t[0] eq "-sd")
		{
			$sd=$t[1];
			$sdir=$sd;
		}
		elsif($t[0] eq "-td")
		{
			$td=$t[1];
			$tdir=$td;
		}
		else
		{
			print "Wrong argument $narg:$arg\n";
			print "Usage: asmlib.pl [-sd=<sourcedir>] [-td=<targetdir>] <libname>\n";
			exit 1;
		}
	}
}

if($narg == 0 || $fi eq "")
{
	print "No or wrong arguments\n";
	print "Usage: asmlib.pl [-sd=<sourcedir>] [-td=<targetdir>] <libname>\n";	
	exit 1;
}

my $lname=$fi;
$fi = $sd . '/' . $fi . ".lib" . ".def";
print "Assemble $fi in source directory:$sdir and store the object files in:$tdir\n";

my $c;
my $fmod;
my @t;
my $exec;
open (IN,$fi) || die "cannot open library definition file $fi: $!";

while(<IN>)
{
	if($DEBUG) {print "$_";}
	$c=substr($_,0,1);
	next if($c eq '#' || $c eq '*'); # skip comment lines
	if($_ =~ ':EOF')
	{
		last;
	}
	@t=split(/\./,$_);
	if($DEBUG) {print "File:@t";}
	$fmod=$t[0];
	$fmod = $fmod . '.src';
	print "Assemble module: $fmod\n";		
	$exec = ".\/p8asm.pl -nl -sd=$sd -td=$td $fmod\n";
	if(system($exec))
	{
		# error
		exec 1;
	}
}
	
close (IN) || die "can't close $fi: $!";
print "Assembly of the library $lname is ready\n";

